@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -190,7 +190,7 @@ void TableFormatDialog::setAlignment(Qt::Alignment alignment)
 
 Qt::Alignment TableFormatDialog::alignment() const
 {
-    return (Qt::Alignment)d->alignment->itemData(d->alignment->currentIndex()).toInt();
+    return static_cast<Qt::Alignment>(d->alignment->itemData(d->alignment->currentIndex()).toInt());
 }
 
 QTextLength::Type TableFormatDialog::typeOfLength() const
