@@ -102,7 +102,7 @@ bool TextUtils::containsFormatting(const QTextDocument *document)
         block = block.next();
     }
 
-    if (document->toHtml().contains(QStringLiteral("<hr />"))) {
+    if (document->toHtml().contains(QLatin1String("<hr />"))) {
         return true;
     }
 
